pub trait AsIx2 {
// Required method
fn as_ix2(self) -> Ix2;
}Expand description
Trait for converting a type into a 2-dimensional index (Ix2).
This trait is implemented for various types, allowing them to be converted into a 2D index, which is useful for indexing into 2D arrays or matrices.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".