pub trait VectorWithLength<const LEN: usize> { }Expand description
Univeral vector.
A trait indicate that entity in case of referencing it can be interpreted as such having specified length LEN.
This trait defines a constant LEN, representing the length of the entity.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl<T, const LEN: usize> VectorWithLength<LEN> for &Twhere
T: VectorWithLength<LEN>,
Implementation of VectorWithLength for references to entities.
impl<T, const LEN: usize> VectorWithLength<LEN> for &mut Twhere
T: VectorWithLength<LEN>,
Implementation of VectorWithLength for mutable references to entities.